﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml.Linq;
namespace LinqTestConsole
{
    class FenixDataPage
    {
        public Int32 DataPageType { get; set; }
        public Int32 DataPageName { get; set; }
        public Int32 DataPageIdx { get; set; }
        public Int32 DataPageCustomIdx { get; set; }
        public List<FenixDataPageField> DataPageFields { get; set; }
        public FenixDataPage()
        {
        }
        public FenixDataPage(Int32 p_DataPageType, Int32 p_DataPageName)
        {
            DataPageType = p_DataPageType;
            DataPageName = p_DataPageName;
        }
        public FenixDataPage(Int32 p_DataPageType, Int32 p_DataPageName, List<FenixDataPageField> p_DataPageFields)
        {
            DataPageType = p_DataPageType;
            DataPageName = p_DataPageName;
            DataPageFields = p_DataPageFields;
        }
        public static List<FenixDataPage> ParseDataPages(XDocument p_XMLContent, String p_PageType)
        {
            var outPages = (from values in p_XMLContent.Descendants(p_PageType)
                               select new FenixDataPage
                               {
                                   DataPageType = (Int32?)values.Element("DataPageType") ?? 0,
                                   DataPageName = (Int32?)values.Element("DataPageName") ?? 0,
                                   DataPageIdx = (Int32?)values.Element("DataPageIdx") ?? 0,
                                   DataPageCustomIdx = (Int32?)values.Element("DataPageCustomIdx") ?? 0,
                                   DataPageFields = GetDataPageFields(values.Descendants())
                               });

            return outPages.ToList();

        }
        public static List<FenixDataPageField> GetDataPageFields(IEnumerable<XElement> p_Nodes)
        {
                var outFields = (from pageFields in p_Nodes
                                 where (pageFields.Element("DataPageField") != null) && (pageFields.Element("DataPageFieldLabel") != null)
                                 select new FenixDataPageField
                                 {
                                     //DataPageField = FenixDataPageField.ToInt(pageFields.Element("DataPageField").ToString()),
                                     //DataPageFieldLabel = FenixDataPageField.ToInt(pageFields.Element("DataPageFieldLabel").ToString())
                                     DataPageField = (String)pageFields.Element("DataPageField"),
                                     DataPageFieldLabel = (String)pageFields.Element("DataPageFieldLabel")
                                 });
            return outFields.ToList();
        }
        public static XElement ToXML(String p_sNodeType, List<FenixDataPage> p_DataPages)
        {
            XElement outElement = null;
            foreach(FenixDataPage thisPage in p_DataPages)
            {
                XElement tempElement = new XElement(p_sNodeType,
                                        new XElement("DataPageType", thisPage.DataPageType),
                                        new XElement("DataPageName", thisPage.DataPageName),
                                        new XElement("DataPageIdx", thisPage.DataPageIdx),
                                        new XElement("DataPageCustomIdx", thisPage.DataPageCustomIdx));
                tempElement.Add(GetInnerElements(thisPage));
                if (outElement == null)
                    outElement = tempElement;
                else
                    outElement.Add(tempElement);
            }
            return outElement;
        }
        private static XElement GetInnerElements(FenixDataPage p_DataPage)
        {
            XElement outElement = null;
            for(int x = 1; x <= p_DataPage.DataPageFields.Count; x++)
            {
                if (outElement == null)
                {
                    outElement = new XElement("DataPageField" + x.ToString(), 
                                                new XElement("DataPageField", p_DataPage.DataPageFields[x - 1].DataPageField),
                                                new XElement("DataPageFieldLabel", p_DataPage.DataPageFields[x-1].DataPageFieldLabel.ToString()));
                }
                else
                {
                    outElement.Add(new XElement("DataPageField" + x.ToString(), 
                                                new XElement("DataPageField", p_DataPage.DataPageFields[x - 1].DataPageField),
                                                new XElement("DataPageFieldLabel", p_DataPage.DataPageFields[x-1].DataPageFieldLabel.ToString())));
                }

            }
            return outElement;
        }
    }
}
